pub struct S3StorageProperty {
pub bucket: String,
pub region: String,
pub prefix: String,
pub endpoint: String,
pub access_key_id: String,
pub secret_access_key: String,
pub virtual_host_style: bool,
}Fields
bucket: StringBucket name.
region: StringRegion name.
prefix: StringURL prefix of table files, e.g. /path/to/my/dir/.
Default to /
endpoint: StringURL of S3 endpoint, e.g. https://s3.<region>.amazonaws.com.
access_key_id: StringAccess key ID.
secret_access_key: StringSecret access key.
virtual_host_style: boolWhether to enable virtual host style, so that API requests will be sent in virtual host style instead of path style.
Default to true